# Centralized Economic Data API

## Introduction

This is a economic data collecting library, with both `python` and `R`

* `python` version: [https://github.com/TerenceLiu98/CEDApy](https://github.com/TerenceLiu98/CEDApy)
* `R` version: [https://github.com/TerenceLiu98/CEDAr](https://github.com/TerenceLiu98/CEDAr) *Not Start Yet*

## Installation

Via the source code

```shell
git clone https://github.com/TerenceLiu98/CEDApy.git
python setup.py install
```

Via the `pypi`:

```shell
python -m pip install CEDApy
```

## How to use

Please check [Wiki](https://github.com/TerenceLiu98/CEDApy/wiki)

## Acknowledgement

* Thanks [akshare](https://github.com/jindaxiang/akshare/)
* Thanks [EastMoney](https://www.eastmoney.com)
* Thanks [St.Louis Federal Reserve Bank](https://fred.stlouisfed.org/)
* Thanks [Chicago Federal Reserve Bank](https://www.chicagofed.org/)
* Thanks [Philadelphia Federal Reserve Bank](https://www.philadelphiafed.org/)
* Thanks [eurostat Economic Indicators](https://ec.europa.eu/eurostat/cache/infographs/economy/desktop/index.html)
* Thanks [Europen Central Bank](https://www.ecb.europa.eu)
* Thanks [MarketWatch](https://www.marketwatch.com/)

## If you want to cite...

```txt
@misc{LIU2021,
  author = {Terence,Junjie-LIU},
  title = {CEDApy: A centralized macro-economic data library},
  year = {2021},
  publisher = {GitHub},
  journal = {GitHub repository},
  howpublished = {\url{https://github.com/TerenceLiu98/CEDApy}},
  url = "https://pypi.org/project/CEDApy/",
  commit = {117e6e61d05af48576a8734c6b87248a380e6114}
}
```